#
# spec file for package publicsuffix
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2015 yaneti@declera.com
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           publicsuffix
Version:        20250520
Release:        1.1
Summary:        Cross-vendor public domain suffix database
License:        MPL-2.0
URL:            https://publicsuffix.org/
Source0:        %{name}-%{version}.tar.gz
BuildRequires:  psl-make-dafsa
BuildArch:      noarch

%description
The Public Suffix List is a cross-vendor initiative to provide
an accurate list of domain name suffixes, maintained by the hard work
of Mozilla volunteers and by submissions from registries.
Software using the Public Suffix List will be able to determine where
cookies may and may not be set, protecting the user from being
tracked across sites.

%prep
%autosetup

%build
psl-make-dafsa \
    --input-format=psl \
    --output-format=binary \
    public_suffix_list.dat public_suffix_list.dafsa

%check
%make_build test-syntax

%install
install -m 644 -p -D public_suffix_list.dat \
  %{buildroot}/%{_datadir}/%{name}/public_suffix_list.dat
ln -s public_suffix_list.dat %{buildroot}/%{_datadir}/%{name}/effective_tld_names.dat
install -m 644 -p -D public_suffix_list.dafsa \
  %{buildroot}/%{_datadir}/%{name}/public_suffix_list.dafsa

%files
%license LICENSE
%{_datadir}/%{name}

%changelog
* Wed May 21 2025 Martin Pluskal <mpluskal@suse.com>
- Update to version 20250520:
  * Actualización de lista de extensiones del dominio ec en orden alfabético (#2420)
  * remove wildcard from `*.my.canvasite.cn` and `*.my.canva.site` (#2477)
  * Add biz.gh and net.gh SLD to Public Suffix List (#2455)
  * util: gTLD data autopull updates for 2025-05-17T15:16:58 UTC (#2480)
  * Update public_suffix_list.dat (#2462)
  * chore: move Appwrite domains (#2467)
  * update email contact for is-a.dev (#2465)
  * merge `Harrison Network` into `William Harrison` (#2463)
  * remove `localhostcert.net` (#2464)
  * remove `PSL Sandbox` (#2460)
  * Add code tags to domains in README
  * fix(readme): remove preceding dots (#2456)
  * util: gTLD data autopull updates for 2025-04-30T15:19:32 UTC (#2454)
  * Adding `onid.ca` (#2452)
  * util: gTLD data autopull updates for 2025-04-26T15:16:32 UTC (#2447)
  * util: gTLD data autopull updates for 2025-04-24T15:19:52 UTC (#2446)
* Thu Apr 24 2025 Martin Pluskal <mpluskal@suse.com>
- Update to version 20250424:
  * Add lp.dev to public_suffix_list.dat (#2391)
  * fix: autopin dependencies (#2430)
  * Run go mod tidy
  * Bump golang.org/x/net from 0.33.0 to 0.38.0 in /tools (#2438)
  * Add mmv.kr / vki.kr (#2442)
  * dev.project-study.com (#2444)
  * add `preview.site` (#2445)
  * Add `luyani.app` (#2440)
  * Add objectstorage.ch (#2439)
  * Add val.run (#2432)
  * Update public_suffix_list.dat (#2437)
  * Add seg.ar to public_suffix_list.dat (#2433)
  * Add convex.app and convex.site (#2436)
  * Add e2b.app (#2431)
  * Add *.devinapps.com (#2435)
  * Add rules for Amazon Cognito (#2366)
  * add `figma.site` (#2429)
* Tue Apr  8 2025 Martin Pluskal <mpluskal@suse.com>
- Update to version 20250407:
  * Add windsurf.app and windsurf.build (#2428)
  * util: gTLD data autopull updates for 2025-03-28T15:18:17 UTC (#2423)
  * feat: add Appwrite domains to the list (#2410)
  * Add storacha.link and w3s.link (#2417)
  * Remove `router.management` (#2409)
  * Add dpdns.org (#2414)
  * Add devinapps.com (#2412)
  * add inbrowser.link and inbrowser.dev (#2413)
  * Update public_suffix_list.dat (#2403)
  * Add ai.kr, io.kr, it.kr, me.kr (#2407)
  * Update pro.typeform.com contact (#2404)
  * Add deus-canvas.com to PSL (#2405)
  * Add oninferno.net (#2402)
  * add deno.net (#2400)
  * util: gTLD data autopull updates for 2025-02-28T15:17:59 UTC (#2401)
  * Add cpanel.site to private section (#2398)
  * Add `zone.id` to the list (#2396)
  * Add *.zerops.app (#2393)
  * util: gTLD data autopull updates for 2025-02-26T15:18:44 UTC (#2397)
* Wed Feb 26 2025 Martin Pluskal <mpluskal@suse.com>
- Update to version 20250224:
  * Add *.square.site for Block, Inc. (#2385)
  * Add emprende.ve (#2394)
  * util: gTLD data autopull updates for 2025-02-21T15:17:09 UTC (#2390)
  * Add Lovable to public_suffix_list.dat (#2379)
* Thu Feb 13 2025 Martin Pluskal <mpluskal@suse.com>
- Update to version 20250212:
  * add bubbleapps.io and cdn.bubble.io to public_suffix_list.dat (#2380)
  * Moved JPRS comment to appropreate position (#2383)
  * Add laravel.cloud to Public Suffix List (#2381)
  * Add alibabacloudcs.com to Public Suffix List (#2373)
  * Add localtonet.com and localto.net (#2237)
  * Add obj.ag to Public Suffix List (#2374)
  * Brave Submissions to the Public Suffix List - Q1 2025 (#2375)
  * Update ug (#2371)
  * Revert "set label on PR based on check result (#2353)" (#2372)
  * Update `ml` (#2369)
  * Bump golang.org/x/net from 0.26.0 to 0.33.0 in /tools (#2370)
  * set label on PR based on check result (#2353)
  * Add subsc-pay suffix domain (#2310)
  * add `edu.vg` (#2367)
  * AWS Submissions to the Public Suffix List - Q4 2024 (#2212)
  * Add Liara (#2365)
* Wed Jan  8 2025 mpluskal@suse.com
- Update to version 20250107:
  * Add `cloudbeesusercontent.io` (#2298)
  * add PSL Sandbox (#2358)
  * Replace broken links (#2360)
  * Add Code of Conduct (#2364)
  * remove Hakaran domains (#2361)
  * chore: formatting + fixes (#2329)
  * remove `curv.dev` (#2317)
  * remove Diher Solutions section (#2319)
  * add botdash domains (#2342)
  * update email address (#2354)
  * remove `spacekit.io` (#2348)
  * remove `drud.io` and `drud.us` (#2347)
  * remove `platter-app.com` (#2346)
  * util: gTLD data autopull updates for 2024-12-23T15:16:32 UTC (#2357)
  * chore: update website URL (#2344)
  * remove `lab.ms` (#2334)
  * remove `n4t.co`, `001www.com`, `now-dns.top` (#2324)
  * remove `secaas.hk` (#2335)
  * util: gTLD data autopull updates for 2024-12-12T15:18:57 UTC (#2341)
  * remove `shiftedit.io` (#2312)
  * fix some URLs (#2340)
  * update `.az` section (#2331)
  * update `.bw` section (#2339)
  * add confirmation message to `.am` (#2330)
  * remove `lelux.site` (#2336)
  * remove `yombo.me` (#2337)
  * Remove blogspot ccTLD domains (#2327)
  * chore(tools/internal/parser): remove unneeded exceptions (#2328)
  * Update comments for `.it`, `.jp`, `.se`, `.xn--fiqs8s`, `.xn--fiqz9s` (#2325)
  * Add addr.tools dynamic dns services (#2320)
  * util: gTLD data autopull updates for 2024-12-10T15:19:18 UTC (#2321)
  * remove `herokussl.com` (#2313)
  * remove `aaa.vodka` (#2323)
  * remove Danger Science section (#2318)
  * add aiven.app to public suffix (#2315)
  * update `.us` (#2316)
  * Update `.PW` (#2314)
  * remove `test.ru` (#2301)
  * Add email policy (#2296)
  * add on-fleek.xyz (#2303)
  * Add `netlib.re` (#2308)
  * rename `GetLocalCert` to `LocalCert` (#2309)
  * update info + add note regarding 2LDs for `.name` (#2307)
  * Add checkbox for contact method to the PR template (#2305)
  * Allow 0e.vc to be isolated for all subdomains by adding wildcard (#2299)
* Wed Dec  4 2024 Martin Pluskal <mpluskal@suse.com>
- Update to version 20241202:
  * remove `upli.io` (#2302)
  * added o365 sub domain (#2291)
  * tools/internal/parser: enforce suffix ordering in the ICANN section (#2295)
  * chore: Fix Alphabetizing for the ICANN section (#2287)
  * remove `mcpe.me` (#2294)
  * util: gTLD data autopull updates for 2024-11-27T15:18:00 UTC (#2293)
  * Update `.EG` Section (#2290)
  * Adding RUB domain (#2292)
  * Update `.TW` Section (#2289)
  * Update `.CV` Section (#2286)
  * Update company name and email address (#2285)
  * Update `.GE` Section (#2283)
  * Update `.BO` (#2276)
  * Update `.DM` Block (#2277)
  * Update `.MG` Section (#2274)
  * chore: Update `.AF` Section link and sorting (#2279)
  * chore: Update `.CW` Section comments (#2281)
  * update `.tt` section (#2272)
  * remove `betainabox.com` (#2259)
  * Update `.AZ` comments and fix sorting (#2275)
  * alphabetise `.tm` section + add confirmation comment (#2268)
  * Update `.RE` Section (#2271)
  * Update `.CO` Section (#2269)
  * Update `.PL` comments and fix alphabetical sorting (#2270)
  * Update `.SG` Section (#2273)
  * Update 2nd levels for .JO (Jordan) section (#2264)
  * remove `nom.ad` (#2263)
  * Update .IS (#2266)
  * Update .AU Section (#2267)
  * Heyflow GmbHs domains heyflow.page and heyflow.site
  * Adding LODMAN regional domains
  * Master to main for the remote action in the website remote
  * chore(pr_template): remove syntax check (#2252)
  * Add pages-research.it.hs-heilbronn.de (#2253)
  * Update deploy-site.yml
  * remove `corpnet.work`, update contact info (#2247)
  * add `co.bz` (#2249)
  * move `wdh.app` to new section (#2246)
  * remove `bci.dnstrace.pro` (#2245)
  * remove `onred.one` (#2244)
  * util: gTLD data autopull updates for 2024-10-31T15:17:41 UTC (#2242)
  * Add home.arpa (#2220)
  * Add `taveusercontent.com` (#2239)
  * Add ip-ddns.com and ddns-ip.net (#2234)
  * Add grafana-dev.net to public suffix list (#2188)
  * chore: remove 2nd level comment for `.sk` (#2238)
  * Remove `presse.ci` and `md.ci`, other ccTLD stubs not associated w respective registry (#2198)
  * update `.io` section (#2236)
  * Remove `gov.cu` (#2233)
  * Remove Handshake suffixes (#2222)
  * internal/parser: add PublicSuffix and RegisteredDomain methods to List (#2228)
  * Add cloud-ip.biz and ip-dynamic.org for ClouDNS (#2202)
  * Add co.ss (#2144)
  * Add `org.ao`, `edu.ao`, `gov.ao` ccTLD (ICANN section) (#2145)
  * util: gTLD data autopull updates for 2024-10-17T15:16:22 UTC (#2226)
  * chore: update is-a.dev contact info (#2225)
  * Remove bloxcms.com in public suffix list - no longer needed (#2224)
  * Remove ddns5.com (#2221)
  * Make TXT validation use local git history (#2217)
  * Improve psltool PR check (#2218)
  * Remove beta.tailscale.net (#2216)
  * util: gTLD data autopull updates for 2024-10-15T15:17:29 UTC (#2219)
  * Remove `museum.mw` (#2203)
  * Update `.NA` entries (#2204)
  * Remove `ne.pw` (#2200)
  * Remove inactive or expired yombo domains (#2173)
  * Remove old Python PR checker
  * Add medusajs.app domain to public list (#2211)
  * Remove Banzai Cloud (#2215)
  * tools/internal/github: correctly handle github's mergeability updates (#2214)
  * tools/internal/parser: check TXT records (#2213)
  * remove `preview.wdh.app`, `t.hrsn.dev`, `t.hrsn.net` (#2208)
  * Update PR Template Requiring Abuse Contact for Subdomain Registry Requestors (#2201)
  * remove `paris.eu.org` (#2147)
  * remove `blogspot.mr` (#2100)
  * Adding ArvanCloud arvanedge.ir Compute Domain to public suffix list (#2205)
  * remove `q-a.eu.org` (#2146)
  * AWS Submissions to the Public Suffix List - Q3 2024 (#2032)
  * Remove `bounty-full.com` to rollback #104 (#2163)
  * Add back `cnpy.gdn` to restore #633 (#2194)
  * Remove `cnpy.gdn` to rollback #633 (#2174)
  * Br 20240930 update (#2192)
  * add mittwald product domains (#2171)
  * util: gTLD data autopull updates for 2024-09-26T15:17:07 UTC (#2191)
  * Remove `certmgr.org` to roll back #225 (#2164)
  * Remove dyn53.io to rollback #820 (#2161)
  * Remove `forte.id` to rollback #1081 (#2166)
  * Remove `daplie.me` to rollback commit a4d8335 (#2162)
  * remove exception in CI for duplicate sections (#2180)
  * combine duplicate sections (#2168)
  * tools/internal/domain: add functions to render a domain as punycode (#2179)
  * tools/psltool: allow checking the PSL for an arbitrary commit on github (#2177)
  * tools/internal/github: support loading PR diffs for merged PRs (#2176)
  * tools/internal: wrap use of collators in mutexes (#2175)
  * Add `hf.space` and `static.hf.space` to `public_suffix_list.dat` (#2157)
  * Update `prvcy.page` contact email (#2182)
  * Add shopware.shop to public suffix list (#2187)
  * Remove domain:ktistory.com from PSL (#2181)
  * rename `William Harrison` to `Harrison Network` (#2183)
  * Remove *.sensiosite.cloud and *.s5y.io (#2167)
  * Remove `mycd.eu` to rollback #233 (#2165)
  * docs(pr_template): fix grammar error + small changes (#2169)
  * add `hrsn.dev` (#2170)
  * add `t.hrsn.dev` (#2155)
  * docs(pr_template): various fixes and comment updates (#2156)
  * util: gTLD data autopull updates for 2024-09-13T15:16:52 UTC (#2154)
  * Apply formatting using `psltool fmt` (#2152)
  * update contact for dweb.link and libp2p.direct (#2105)
  * Automatically run psltool validate (#2151)
  * Add v0.build and vusercontent.net (#2121)
  * Cleanup (#2150)
  * chore: remove 6 domains from Now-DNS section (#2113)
  * Remove old Jelastic domains (from #1095) (#2148)
  * Add `ctfcloud.net` domain (#2073)
  * remove `mc.eu.org` (#2099)
  * Add gob.cu nat.cu (#1695) (#2143)
  * remove `dapps.earth` section (#2124)
  * Remove `autocode.dev` (Rollback #1617) (#2141)
  * remove `magnet.page` (#2142)
  * Apply formatting using `psltool fmt` (#2140)
  * Minor formatting fix (#2139)
  * Add psltool fmt check for PRs (#2137)
  * Replace Legacy Wikipedia URLs with IANA Page Links in ICANN Section Comments (#2135) (#2138)
  * UPDATE HOSTBIP DOMAIN NAMES (2024) +biz.ng +plc.ng -edu.scot -sch.so (#2127)
  * Adding oraclecloudapps.com from Oracle Autonomous Database (#2130)
  * Remove flap.id (#2132)
  * Remove discontinued CentralNic entries (#2136)
  * Apply formatting using `psltool fmt` (#2134)
  * Add new action to manually run formatter (#2133)
  * add `nyat.app` (#2122)
  * Remove `publishproxy.com` (#294) (#2131)
  * Update public_suffix_list.dat (#2128)
  * Remove `fireweb.app` (#2129)
  * Update contact information for `nyc.mn` (#2125)
  * Fix syntax inconsistency (#2126)
  * add `preview.wdh.app` and `t.hrsn.net` (#2119)
  * Move Domains Under OpenHost (#2115)
  * util: gTLD data autopull updates for 2024-08-25T15:14:38 UTC (#2111)
  * remove `bip.sh` (#2063)
  * Add routingthecloud.com/.net/.org (#2107)
  * remove Revitalised Limited section (#2101)
  * chore: update contact info + revert wildcard change for `wdh.app` (#2108)
  * remove `blogsite.xyz` (#2098)
  * Add additional readthedocs domain: readthedocs-hosted.com (#2110)
  * Add MathWorks domains  (#1983)
  * remove localzone.xyz (#2104)
  * add `is-a-good.dev` (#2095)
  * util: gTLD data autopull updates for 2024-08-12T15:17:08 UTC (#2103)
  * merge `wdh.app` entries together using wildcard (#2094)
  * add `is-a-fullstack.dev` under Open Domains (#2096)
  * Fix newline handling of automatic ICANN updater (#2093)
  * util: gTLD data autopull updates for 2024-08-10T15:15:39 UTC (#2097)
  * Add IONOS product domains (#2083)
  * add ggff.net and filegear-sg.me from l53.net (#2085)
  * add `wdh.app` (#2067)
  * add libp2p.direct (#2084)
  * add sn.mynetname.net domain (#2090)
  * Update public_suffix_list.dat (#2076)
  * Run 'psltool fmt' to reformat PSL to canonical form (#2088)
  * tools/psltool: support for analyzing a github PR (#2087)
  * tools/internal/parser: add more offline, diff-aware validations (#2089)
  * Add `mafelo.net` (#2082)
  * remove `devcdnaccesso.com` (#2065)
  * remove `t3l3p0rt.net` and `tele.amune.org` (#2066)
  * remove `bitbridge.net` (#2064)
  * remove static.land from public_suffix_list.dat (#2081)
  * Remove wedeploy domains (#2077)
  * update for .PK ccTLD (#2068)
  * Remove `awsmppl.com` (expired domain) (#2070)
  * update contact email for `is-a.dev` (#2074)
  * remove old domains (#2058)
  * Update README.md
  * remove cloudcontrol.com (#2072)
  * tools/internal/parser: add diff support (#2071)
  * remove`graphox.us` (#2062)
  * Remove `pagefrontapp.com` (expired domain) (#2059)
  * tools/psltool: CLI for editing and validating PSL files (#2069)
  * Remove `mozilla-iot.org` (#2050)
  * Remove Shift Crypto AG (#2055)
  * Remove `backplaneapp.io` to rollback #267 (expired domain) (#2060)
  * remove `pcloud.host` (#2052)
  * Remove `mintere.site` to rollback #993 (#2056)
  * remove `cya.gg` (#2053)
  * remove `nid.io` (#2054)
  * remove Cyclic Software section (#2051)
  * Remove `onflashdrive.app` (related to #1401) (#2048)
  * Remove impertrix domains to rollback #1060 (#2047)
  * Remove filegear regional domains (#2049)
  * remove `c.la` (#2044)
* Mon Jul 22 2024 Martin Pluskal <mpluskal@suse.com>
- Update to version 20240722:
  * PSL Private Section Domains WHOIS Checker (#2014)
  * Add servebolt.cloud to PLS (#2026)
  * Add `p.tawk.email` and `p.tawkto.email` domains (#2016)
  * Remove domain no longer under Supabase control. (#2037)
  * tools/internal/parser: implement automatic reformatting (#2036)
  * util: gTLD data autopull updates for 2024-07-12T15:14:39 UTC (#2034)
  * Add dhosting.pl Sp. z o.o. shared domains: dfirma.pl, dkonto.pl, you2.pl (#2024)
  * tools/internal/parser: rework metadata extraction for more accurate reformatting (#2027)
  * AWS Submissions to the Public Suffix List - Q2 2024 (#1954)
  * aero: remove extra word between TLD name and URL (#2029)
  * tools/internal/parser: rewrite parser to output a syntax tree (#2025)
  * Add removal notice to PR template (#2023)
  * remove Rakuten Games, Inc related entries (#2022)
  * add `hatenablog.com` etc (#1948)
  * Add cyber_Folks S.A. shared domain - cfolks.pl (#2017)
  * tools/internal/parser: minor parser cleanups (#2021)
  * Add Craft Docs Domain (#2006)
  * util: gTLD data autopull updates for 2024-06-29T15:13:33 UTC (#2020)
  * Merge WebPros domains in the same section (#2013)
  * Add `durumis.com` (#1978)
  * tools/internal/parser: validate the sort order of the private section (#2012)
  * Update comments on aland.fi (#2019)
  * Remove instantcloud.cn (#2015)
  * tools/internal/parser: detect and report section markers within suffix blocks (#2011)
  * tools/internal/parser: remove workarounds for fixed PSL blocks (#2010)
  * Add Raidboxes GmbH to the list (#2004)
  * Add missing URL schemes to URLs (#2008)
  * Add closing chevron to contact email address. (#2007)
  * tool/internal/parser: sanitize input to clean, valid UTF-8 (#2005)
  * Add `obl.ong` (#1830)
  * Salesforce crm dev (#1941)
  * Add wpsquared.site and wp2.host to private section (#1957) (#1957)
  * Add netfy.app (#1991)
  * Remove expired domains: `ro.im`, `cn.vu` (#2003)
  * tools/internal/parser: refactor to separate text processing from parser main logic (#1999)
  * Replace unicode fullwidth colon with a regular ascii colon. (#2001)
  * Add missing spaces after '//' on prequalifyme.today block (#2000)
  * Add `as.sh.cn` (#1992)
  * tools: add a validating parser for PSL files (#1987)
  * Clarify request to list third-party limits in PR template
  * util: gTLD data autopull updates for 2024-06-13T15:15:16 UTC (#1994)
  * Reattach of.by to the Belarus ccTLD block (#1995)
  * add madethis.site (#1979)
  * mytuleap.com, tuleap-partners.com: update contact information (#1845)
  * Add Strapi domains (#1982)
  * Add relay.evervault.app and relay.evervault.dev (#1959)
  * add .ind.mom  (#1984)
  * Add 6 new domains to Lukanet Ltd Private domains (#1977)
  * Add heiyu.space (#1980)
* Thu Jun  6 2024 Martin Pluskal <mpluskal@suse.com>
- Update to version 20240603:
  * Add Cloudflare CNAME setup domains (#1963)
  * util: gTLD data autopull updates for 2024-05-31T15:16:08 UTC (#1988)
  * Add `hypernode.io` domain (#1970)
  * Add `wixstudio.com` (#1971)
  * Fix set union (#1986)
  * Bump dnspython from 2.5.0 to 2.6.1 in /tools/pr_checker (#1985)
  * Add Github workflow to check _psl DNS entries on PRs (#1933)
  * Clean up list to fix rule sorting within orgs (#1968)
* Fri May 17 2024 Martin Pluskal <mpluskal@suse.com>
- Update to version 20240513:
  * Add Expo domains (#1975)
  * Add `*.hosted.app` (#1947)
  * Add Clever Cloud's domains for customers (#1974)
  * Add web.val.run and express.val.run to PSL (#1964)
  * add notion site to etld (#1958)
  * Add `box.ca` (Whatbox) (#1950)
  * Add observablehq.cloud (#1934)
  * Add "zeabur.app" (#1865)
  * Add `sheezy.games` (#1945)
  * util: gTLD data autopull updates for 2024-05-04T15:12:50 UTC (#1973)
  * Create a Security Policy (#1856)
  * Add examples of limitations to PR template (#1929)
  * Update `prvcy.page` (#1859)
  * Remove Lightmaker Property Manager, Inc. domain (#1820)
  * Adding regional domain bielsko.pl (#1749)
  * add xmit.dev (#1972)
  * Remove `ghost.io` (#1969)
  * Add aaa.vodka (#1795)
  * Add ngo.us for the NGO.US Registry (#1821)
  * AWS Submissions to the Public Suffix List - Q1 2024 (#1919)
  * Add shop.brendly.hr (#1762)
* Thu Apr 25 2024 Martin Pluskal <mpluskal@suse.com>
- Update to version 20240419:
  * add qnap entries to existing section (`myqnapcloud.cn` , `mycloudnas.com`, `mynascloud.com`) (#1837)
  * Update public_suffix_list.dat (#1966)
  * drop old domains (#1960)
  * Jouwweb public suffixes (#1935)
  * Add `us.kg` (#1755)
  * Replacement for PR #1741 (#1962)
  * Add `rt.ht` (#1860)
  * Add cloudscale.ch domains (#1589)
* Wed Apr 10 2024 mpluskal@suse.com
- Update to version 20240410:
  * Removing `ravendb.me` (#1841)
  * Updating psl: Adding myfritz.link (follow up PR#77) (#1761)
  * Add `framer.ai` (#1831)
  * chore: add `is-a.dev` (#1949)
  * Add StackBlitz (#1939)
  * Add `unison-services.cloud` (#1839)
  * Add `is-cool.dev`, `is-local.org`, `is-not-a.dev` and `localplayer.dev` (#1672)
  * Add grayjayleagues.com (#1742)
  * Add `runcontainers.dev` for Libre IT Ltd (#1783)
  * Add `heliohost.us`, `helioho.st`(#1825)
  * Remove `123sait.ru` (#1844)
  * Add MyDNS.JP Dynamic DNS Service (#1937)
  * add `scrypted.io` (#1826)
  * Add `darklang.io` (#1880)
  * Update `cloudns.net` dynamic dns domains listing (#1593)
  * Add wildcard to `snowflake.app` and `privatelink.snowflake.app` (#1743)
  * Add `preview.csb.app` and `csb.app` (#1648)
  * Add `nimsite.uk` (#1797)
  * add getlocalcert.net domains (#1798)
  * Add wadl.top (#1924)
  * ADD: `can.re` (#1651)
  * Add cdn77-storage.com and rsc.contentproxy9.cz (#1882)
  * add `srv.us`, `xmit.co`
  * Add at.emf.camp (#1955)
  * util: gTLD data autopull updates for 2024-03-28T15:13:37 UTC (#1952)
* Thu Mar 28 2024 Martin Pluskal <mpluskal@suse.com>
- Update to version 20240326:
  * Add `*.ir.md` (#1625)
  * Update name for info.cx (#1616)
  * add `nftstorage.link` (#1548)
  * GD - graphic.design (#1940)
  * Removing wildcard for cloudapp.azure.com (#1944)
* Thu Mar 14 2024 Martin Pluskal <mpluskal@suse.com>
- Update to version 20240306:
  * util: gTLD data autopull updates for 2024-03-06T15:14:58 UTC (#1943)
* Mon Mar  4 2024 Martin Pluskal <mpluskal@suse.com>
- Update to version 20240303:
  * add `*.my.canvasite.cn` and `*.my.canva.site` (#1739)
  * Add on.crisp.email (Crisp IM SAS) (#1904)
  * add `ngrok.pro` (#1895)
  * Add adaptable.app domain (#1824)
  * Add STACKIT free customer subdomains (#1785)
  * Add `modx.dev` (#1804)
  * Add `ewp.live` (EasyWP) (#1773)
  * Add convex.site (#1767)
  * Add `involve.me` user domains (#1731)
  * Add `replit.app` and `replit.dev` (#1679)
  * Add f5.si (#1664)
  * Add *.c.ts.net. (#1618)
  * Add `webflow.io` and `webflowtest.io` (#1722)
  * Add 3 Streak domains (#1720)
  * add myradweb.net and servername.us to Rad Web Hosting (#1760)
* Tue Feb 13 2024 Martin Pluskal <mpluskal@suse.com>
- Update to version 20240212:
  * Add cprapid.com suffix to private section (#1892)
  * util: gTLD data autopull updates for 2024-02-08T15:13:14 UTC (#1932)
  * Added Cyclic Software (#1737)
  * Update public_suffix_list.dat for scw.cloud subdomains (#1740)
  * Update public_suffix_list.dat (#1926)
  * Add ZAP-Hosting cloud domain (#1907)
  * Add `flutterflow.app` (#1666)
  * Update public_suffix_list.dat (#1614)
  * Brave Submissions to the Public Suffix List - Q4 2023 (#1872)
  * Add pley.games (#1881)
  * Add panel.dev (#1916)
  * add 12CHARS to private domains (#1915)
  * Azure updates for Microsoft Corporate Domains (#1891)
  * Remove blog.kg from private section (#1840)
  * AWS Submissions to the Public Suffix List - Q4 2023 (#1876)
  * Homebase requested the addition of id.pub kin.one kin.pub (#1768)
  * Replace run.app and a.run.app with *.run.app (#1928)
  * Add pages.gay (#1920)
  * Update Platform.sh domains (#1792)
  * fix(adobe): add aem.live and aem.page domains (#1874)
  * Update code builder domains with the canary (#1802)
  * Add atmeta.com to PSL and consolidate Meta entries (#1736)
  * util: gTLD data autopull updates for 2024-01-24T15:14:29 UTC (#1923)
* Wed Jan 24 2024 Martin Pluskal <mpluskal@suse.com>
- Update to version 20240123:
  * util: gTLD data autopull updates for 2024-01-23T15:14:10 UTC (#1921)
* Tue Jan  9 2024 Martin Pluskal <mpluskal@suse.com>
- Update to version 20240107:
  * Remove homeoffice.gov.uk (#1909)
  * util: gTLD data autopull updates for 2024-01-06T15:12:04 UTC (#1918)
* Mon Dec 18 2023 Martin Pluskal <mpluskal@suse.com>
- Update to version 20231213:
  * util: gTLD data autopull updates for 2023-12-12T15:13:54 UTC (#1910)
  * util: gTLD data autopull updates for 2023-12-06T15:14:08 UTC (#1908)
  * Place -v after -C in github actions workflows (#1906)
  * Introduce Go Modules to tooling (#1901)
  * util: gTLD data autopull updates for 2023-11-21T15:13:46 UTC (#1902)
  * Handle EBEROs: Use DelegationDate alongside ContractTerminated (#1894)
  * util: gTLD data autopull updates for 2023-11-18T15:11:52 UTC (#1898)
* Tue Nov 14 2023 Martin Pluskal <mpluskal@suse.com>
- Update to version 20231108:
  * Update public_suffix_list.dat (#1848)
  * util: gTLD data autopull updates for 2023-11-03T15:13:18 UTC (#1887)
  * Add `torun.pl` (#1684)
* Tue Oct 31 2023 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 20231028:
  * util: gTLD data autopull updates for 2023-10-28
  * AWS Submissions to the Public Suffix List - Q3 2023
  * Add <4-8>.azurestaticapps.net DNS suffix
* Sun Oct  8 2023 andreas.stieger@gmx.de
- Update to version 20230930:
  * util: gTLD data autopull updates for 2023-09-30T15:11:25 UTC
  * Update .fr list, move some subspaces to PRIVATE section listing of smallregistry.net
  * Remove k12.de.us
  * Add wix.run
* Tue Aug 29 2023 Martin Pluskal <mpluskal@suse.com>
- Update to version 20230826:
  * util: gTLD data autopull updates for 2023-08-26T15:11:07 UTC (#1835)
  * util: gTLD data autopull updates for 2023-08-23T15:12:41 UTC (#1832)
  * Update tld-update.yml (#1827)
  * util: gTLD data autopull updates for 2023-08-12T15:10:57 UTC (#1829)
  * util: gTLD data autopull updates for 2023-08-09T15:14:39 UTC (#1828)
  * tools: include IANA TLD URL in new gtld updates. (#1817)
  * util: gTLD data autopull updates for 2023-08-05T15:11:19 UTC (#1822)
  * Update tld-update.yml to automatically add labels when autopull catches deltas and generates PR (#1815)
  * ci: update test workflow triggers to include PRs. (#1818)
  * util: gTLD data autopull updates for 2023-08-02T15:11:59 UTC (#1816)
  * unbroke URL assembly
  * Add IANA DB URL instead of blanking out contract date
  * tools: skip contract date rendering, small CI fixups. (#1812)
  * util: gTLD data autopull updates for 2023-07-28T15:13:22 UTC (#1805)
* Fri Jul 28 2023 Martin Pluskal <mpluskal@suse.com>
- Update to version 20230717:
  * Domains are removed `hidora.com`, `users.scale.virtualcloud.com.br`, `clicketcloud.com` (#1598)
  * Add storipress.app (#1583)
* Mon Jul 10 2023 Martin Pluskal <mpluskal@suse.com>
- Update to version 20230709:
  * util: gTLD data autopull updates for 2023-07-08T15:13:17 UTC (#1796)
  * util: gTLD data autopull updates for 2023-07-01T15:13:05 UTC (#1791)
  * AWS Submissions to the Public Suffix List - Q1 2023 (#1600)
* Tue Jun 27 2023 Martin Pluskal <mpluskal@suse.com>
- Update to version 20230616:
  * Add 63 geographical domains for .vn ccTLD (#1776)
  * util: gTLD data autopull updates for 2023-06-16T15:12:40 UTC (#1778)
  * util: gTLD data autopull updates for 2023-06-14T15:13:06 UTC (#1777)
* Wed Jun 14 2023 Martin Pluskal <mpluskal@suse.com>
- Update to version 20230613:
  * Add `{id,io,ai}.vn` for .vn ccTLD in ICANN Section (#1771)
  * util: gTLD data autopull updates for 2023-06-10T15:11:56 UTC (#1774)
* Fri Jun  9 2023 Martin Pluskal <mpluskal@suse.com>
- Update to version 20230607:
  * util: gTLD data autopull updates for 2023-06-07T15:13:30 UTC (#1772)
  * Add test workflow (#1750)
  * Update of gov.pl labels (#1752)
* Thu Apr 27 2023 santiago.zarate@suse.com
- Update to version 20230426:
  * Update public_suffix_list.dat (#1747)
  * Update README.md - added link to sorting
* Tue Apr 18 2023 Martin Pluskal <mpluskal@suse.com>
- Update to version 20230414:
  * util: gTLD data autopull updates for 2023-04-14T15:13:16 UTC (#1738)
  * Change - update comments/policy for the French ccTLDs (`.fr`, `.pm`, `.re`, `.tf`, `.wf`, `.yt`) by Administrator (#1732)
  * New policy for .museum, without all the SLD (Second-Level Domains) (#1729)
  * Add ladesk.com (#1538)
  * util: gTLD data autopull updates for 2023-03-18T15:13:12 UTC (#1723)
  * util: gTLD data autopull updates for 2023-03-08T15:15:40 UTC (#1714)
  * Additional ngrok domains - more `ngrok.io` from #48 + `ngrok.app` `ngrok-free.app` `ngrok.dev` `ngrok-free.dev` `ngrok.pizza` (#1653)
  * Add `ie.ua` (#1597)
* Mon Feb 27 2023 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 20230226:
  * TLD and gTLD data updated
  * add SAKURA Internet Inc. domains
  * Add 3.azurestaticapps.net DNS suffix
  * Add subset of Akamai domains to the PSL
  * Add it.com
  * Add Snowflake private domains
  * add canva-apps.com and canva-apps.cn
  * add fastly-edge.com
  * Add Adobe Developer Platform domains
  * Add autocode.dev
  * update .bj
* Wed Nov 30 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 20221129:
  * util: gTLD data autopull updates for 2022-11-29T15:14:18 UTC (#1658)
  * Add activetrail.biz (#1655)
  * Add `cf-ipfs.com`, `cloudflare-ipfs.com`, and `r2.dev` (#1582)
  * Added mytabit.co.il; mytabit.com; (#1499)
  * removing tbits.me from public suffix list (#1642)
* Mon Nov 14 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 20221107:
  * Add myamaze.net (#1602)
  * Remove gwiddle.co.uk (#1638)
  * Removing domain that expired and is not used (#1643)
  * util: gTLD data autopull updates for 2022-11-02T15:17:39 UTC (#1641)
  * Fix typos in pull request template (#1639)
  * util: gTLD data autopull updates for 2022-10-29T15:16:24 UTC (#1636)
  * util: gTLD data autopull updates for 2022-10-20T15:22:14 UTC (#1632)
  * util: gTLD data autopull updates for 2022-10-15T15:17:50 UTC (#1631)
  * Use CentralNic model for Amazon suffixes (#1629)
  * Names.of.London is no longer operating the service (#1630)
  * Domains from simplesite.com used for  subdomain style webhosting of individual customer websites. (#1623)
  * Add Fastmail user content domain user.fm (#1601)
  * util: gTLD data autopull updates for 2022-10-11T15:20:32 UTC (#1626)
  * util: gTLD data autopull updates for 2022-10-07T15:19:56 UTC (#1624)
  * Add *.on-acorn.io (#1578)
  * Update existing Replit entries, add `firewalledreplit.co` (#1568)
  * Add 2.azurestaticapps.net DNS suffix (#1604)
  * Update Pull Request Form to address #1619
  * Add rules for AWS Cloud9 (#1590)
  * util: gTLD data autopull updates for 2022-09-15T15:17:33 UTC (#1615)
* Wed Sep 14 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 20220903:
  * util: gTLD data autopull updates for 2022-09-03T15:15:24 UTC (#1606)
  * Update public_suffix_list.dat (#1594)
  * Add streamlitapp.com (#1591)
  * Update public_suffix_list.dat (#1573)
  * Add Framer Sites domains to PSL (#1570)
  * new TLD .ישראל and SLDs for Israel by ISOC-IL (#1595)
* Wed Aug 10 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 20220805:
  * Updates to NIXI `.in` subspace in ICANN section of PSL (#1588)
  * util: gTLD data autopull updates for 2022-07-28T15:14:54 UTC (#1592)
  * util: gTLD data autopull updates for 2022-07-03T15:13:52 UTC (#1587)
  * Add messerli.app (#1535)
  * Add iservschule.de, schulplattform.de, update IServ GmbH contact information (#1580)
  * Add `lolipopmc.jp` (#1555)
  * Add ibxos.it and iliadboxos.it domains (#1549)
  * Simplify the instance and endpoint domains using wildcard syntax (#1584)
  * util: gTLD data autopull updates for 2022-06-14T15:15:19 UTC (#1581)
  * doc (.in): update ref uri to registry policies (#1577)
  * util: gTLD data autopull updates for 2022-06-02T15:16:31 UTC (#1579)
* Tue May 31 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 20220518:
  * util: gTLD data autopull updates for 2022-05-18T15:16:02 UTC (#1567)
  * fixed wordwrap; added # of users q
  * Add builder.code.com, stg-builder.code.com, and dev-builder.code.com (#1566)
  * UPDATE HOSTBIP RECORDS (`name.pm` `sch.tf` `biz.wf` `sch.wf` `org.yt`) (#1473)
  * Fix comments delete space and deprecation of io/ioutil (#1557)
* Wed May 11 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 20220510:
  * Cleaned up the wording and formatting
  * Clarified 3rd party workaround stuff; fixed #1559
  * Add gov.nl (#1558)
  * util: gTLD data autopull updates for 2022-04-30T15:14:45 UTC (#1564)
* Tue Apr 19 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 20220415:
  * util: gTLD data autopull updates for 2022-04-14T15:15:34 UTC (#1554)
  * Add `1.azurestaticapps.net` DNS suffix (#1514)
  * add support for scaleway subdomains (#1507)
* Tue Apr  5 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 20220405 (bsc#1198068):
  * Update .AE policy link
  * Add new `direct.quickconnect.cn` domain to Synology dynamic dns service. (#1547)
  * util: gTLD data autopull updates for 2022-03-27T15:13:37 UTC (#1546)
  * Add user.localcert.dev (#1459)
  * Add Airkit domains (#1501)
  * Add domains for encore.dev (#1531)
  * util: gTLD data autopull updates for 2022-03-24T15:14:59 UTC (#1544)
  * util: gTLD data autopull updates for 2022-03-22T15:14:59 UTC (#1542)
  * Add: campaign.gov.uk (#1536)
  * fix: Fixed spelling errors in PSL (#1530)
* Tue Mar 15 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 20220304:
  * Add deta.app and deta.dev (#1511)
  * Add typedream.app (#1509)
  * Add `musician.io` - updates Staclar entry from #1331 (#1532)
  * Remove couk.me and ukco.me from private section (#1519)
  * add `*.build.run`, `*.database.run` and `*.migration.run` to PSL (#1498)
  * Add ktistory.com (#1493)
  * Remove WapBlog Suffix (#1510)
  * Add `aivencloud.com` (#1508)
  * Add site.transip.me (#1524)
  * Add 105 `lolipop` and `heteml` domains to private section for GMO (#1522)
  * Add `tech.orange` (#1526)
  * Add rocky.page (#1491)
  * Add messwithdns.com (#1490)
  * Revise policy links for `.ac` `.io` `.sh` (#1528)
  * Add kapsi.fi to PSL (#1476)
  * Add translated.page (#1478)
  * Add discordsays.com and discordsez.com (#1474)
  * Add `onporter.run` (#1483)
  * util: gTLD data autopull updates for 2022-02-18T15:13:38 UTC (#1525)
  * Update `.cy` per request from nic.cy in Issue 1516 (#1517)
  * add `*.beget.app` (#1470)
  * Add `vultrobjects.com` and future regional subdomains (#1472)
* Tue Feb  8 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 20220202:
  * util: gTLD data autopull updates for 2022-02-02T15:12:37 UTC (#1513)
  * Add: GDS Managed Domains (#1512)
  * Add CDDO's `api.gov.uk` domain (#1505)
  * Remove: `gov.ky` (#1503)
  * Add `site.tb-hosting.com` for team.blue (#1481)
  * Add codeberg.page to PSL (#1482)
* Tue Jan  4 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 20211230:
  * util: gTLD data autopull updates for 2021-12-30T15:13:57 UTC (#1494)
  * util: gTLD data autopull updates for 2021-12-22T15:14:13 UTC (#1492)
* Tue Dec 21 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 20211213:
  * Adding ravendb.cloud domain to allow separation between users (#1468)
* Wed Dec  8 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 20211207:
  * Add encoway domain: eu.encoway.cloud (#1430)
  * feat: Add pro.typeform.com to PSL (#1457)
  * added cloud.nospamproxy.com (#1455)
  * Replace edugit.org with edugit.io and add s3.teckids.org for Teckids (#1463)
  * Remove nodum domains (#1444)
  * Please add koobin.events to the PSL (#1462)
  * Add 9 BASE, Inc. domains to private section (#1420)
  * Adding Hoplix domains (#1405)
  * util: gTLD data autopull updates for 2021-12-04T15:13:28 UTC (#1484)
  * Revert "Add amsw.nl private domain to PSL (#929)" (#1475)
  * REMOVAL of virtueeldomein.nl (#1480)
* Tue Nov 23 2021 mpluskal@suse.com
- Update to version 20211113:
  * util: gTLD data autopull updates for 2021-11-13T15:12:42 UTC (#1469)
* Thu Nov 11 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 20211109:
  * Added FlashDrive.io domain names (#1401)
  * Remove: gb.com (#1467)
  * util: gTLD data autopull updates for 2021-10-28T15:13:34 UTC (#1464)
  * Remove elluciancrm domains (#1443)
* Wed Oct 20 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 20211016:
  * Fix sorting of One.com domains
  * Add siiites.com (#1416)
  * Add ts.net and beta.tailscale.net domains. (#1453)
  * Revise Sorting for Cape Verde (.cv)
  * Update public_suffix_list.dat (#1456)
  * updated email address (#1450)
  * util: gTLD data autopull updates for 2021-10-08T15:12:46 UTC (#1451)
  * add ip.linodeusercontent.com (#1448)
  * Adding upli.io (#1446)
  * added tickets.io (#1429)
  * util: gTLD data autopull updates for 2021-10-07T15:11:34 UTC (#1449)
  * util: gTLD data autopull updates for 2021-10-06T15:12:57 UTC (#1447)
* Wed Oct  6 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 20211006:
  * Update Pull Request Template to add clarity
  * util: gTLD data autopull updates for 2021-10-01T15:13:10 UTC (#1445)
* Thu Sep 30 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 20210928:
  * Remove Clic2000 entries (#1434)
  * ondigitalocean.app: update comment for DigitalOcean App Platform (#1431)
  * add prequalifyme.today to private section (#1311)
  * util: gTLD data autopull updates for 2021-09-28T15:12:52 UTC (#1438)
  * Add *.usercontent.goog (#1417)
  * Add digitaloceanspaces.com & regional subdomains (#1421)
  * Update public_suffix_list.dat (#1426)
* Tue Sep 21 2021 mpluskal@suse.com
- Update to version 20210909:
  * Adding new .ar SLDs and official nic.ar URL correction (#1414)
* Thu Sep  9 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 20210908:
  * Add instances.spawn.cc (#1411)
  * Remove: nctu.me (#1407)
  * Roll back diher.solutions PR #1393 (#1406)
  * Update public_suffix_list.dat (#1390)
  * Add barsy.ro to Lukanet Ltd private domains (#1402)
  * Add affinitylottery.org.uk raffleentry.org.uk and weeklylottery.org.uk to public suffix list (#1398)
  * Tabitorder.co.il (#1385)
  * add diher.solutions and rss.my.id to the list (#1393)
  * Include *.cloudera.site to the PSL (#1400)
  * Adds pages.it.hs-heilbronn.de (#1388)
  * these domains are being deprecated, we wish to clean up after ourselves (#1399)
* Wed Aug 25 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 20210823:
  * Adding Ellucian subdomains (#1387)
  * add ecommerce-shop.pl (#1373)
  * add homesklep.pl domain (#1372)
  * Updating .ve (Venezuela) entries and contact (#1397)
  * Add clerk.app and clerkstage.app (#1389)
  * util: gTLD data autopull updates for 2021-08-19T15:13:51 UTC (#1396)
  * Add Smoove private domain (#1351)
  * Update CONTRIBUTING.md sort sort sort guidelines
  * util: gTLD data autopull updates for 2021-08-05T15:14:19 UTC (#1391)
  * DEL whole nymnom section due to mass atrophy (#1392)
* Thu Aug  5 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 20210804 (bsc#1189124):
  * Add elementor.cloud and elementor.cool (#1386)
  * add eero ddns domains (#1359)
  * add Adobe Project Helix domains to the list (#1378)
  * util: gTLD data autopull updates for 2021-07-24T15:13:29 UTC (#1384)
  * Add Spreadshop hosting domains: myspreadshop.com plus country-specific (#1368)
  * Add Supabase domains (#1363)
  * Add YunoHost DynDns domains: ynh.fr (#1380)
  * Update public_suffix_list.dat (#1376)
  * add new domains for thingdust AG (#1361)
  * Update public_suffix_list.dat (#1381)
  * Adding sellfy.store pages which render user generated content (#1379)
  * Add itcouldbewor.se to public suffix list (#1375)
  * Adding bitbucket.io pages which render user generated content (#1374)
  * Add rs.ba suffix (#1367)
  * Add tuleap-partners.com (#1360)
  * Add drr.ac and ju.mp (#1355)
  * Add cdn.prod.atlassian-dev.net (#1357)
  * Remove uwu.nu (#1377)
  * util: gTLD data autopull updates for 2021-07-22T15:14:11 UTC (#1382)
* Tue Jul 20 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 20210707:
  * util: gTLD data autopull updates for 2021-07-07T15:17:15 UTC (#1369)
  * util: gTLD data autopull updates for 2021-06-26T15:13:32 UTC (#1362)
* Wed Jun 23 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 20210615:
  * Removing a private subregistry in .CL due to deprecation. (#1352)
  * Add ddns5.com to private section (#1353)
  * Add shop.brendly.rs (#1309)
  * add mediatech.by and mediatech.dev domains (#1333)
  * newgtlds.go : update Autopull - Added URL for the IANA PSL for #1325 (#1347)
  * Add minisite.ms (#1344)
  * Revert "Add multibaas.app and multibaas.com (#1233)" (#1337)
  * Add appudo.net (#1340)
  * Adding adimo.co.uk (#1343)
  * Add postman dev domains (#1339)
  * Reverting change
  * set default project to list modification and assign to jothan
  * Tickboxes and text added to help reduce self-harm requests
  * submitter affirm not working around 3p limits; ask DNS leaf remain
  * Remove github.dev from PSL (#1335)
  * Add novecore.site (#1331)
  * Add jotelulu.cloud (#1330)
  * Add bluebite.io (#1313)
  * Added onavstack.net (#1299)
  * Update public_suffix_list.dat (#1273)
* Tue May 25 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 20210519:
  * Update Contributing.md
  * Change domain list for PE Ulyanov Kirill Sergeevic (#1306)
  * Remove wildcard (#1318)
* Fri May 14 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 20210511:
  * util: gTLD data autopull updates for 2021-05-11T15:13:51 UTC (#1316)
  * Add authgearapps.com authgear-staging.com (#1304)
  * Add goupile.fr (#1307)
  * Add hosp.uk to our existing domains (#1308)
  * Update README.md
  * Add noop.app and *.developer.app to PSL (#1265)
  * Add github dev domains (#1290)
  * added Storebase.store (#1291)
  * Update to pythonanywhere entries (#1298)
  * Update README.md - added Apple / Facebook note
  * addition of ss sld's sch.ss and me.ss (#1247)
  * util: gTLD data autopull updates for 2021-04-22T15:17:15 UTC (#1292)
* Tue Apr 20 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 20210419:
  * exclude gov.st from publicsuffix since host act as public domain (#1257)
  * util: gTLD data autopull updates for 2021-04-17T15:15:54 UTC (#1284)
  * Add wixsite.com and editorx.io (#927)
  * Update public_suffix_list.dat (#1263)
  * Adding reserve-online.net, reserve-online.com, bookonline.app, hotelwithflight.com (#1254)
  * Update Platform.sh domains (#1256)
  * New Jelastic public domains are added and existing ones are reviewed (#1259)
* Wed Mar 31 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 20210330:
  * Fix-up ordering of entries (#1255)
  * Adding mazeplay.com (#1253)
  * Adding Tradable Bits (#1240)
  * Update forgeblocks, add subdomain to psl (#1252)
  * Additional suffix `id.repl.co` for Repl.it (#1239)
  * Add ravpage.co.il (#1250)
  * accesso - Adding devcdnaccesso (#1248)
  * util: gTLD data autopull updates for 2021-03-27T15:15:49 UTC (#1249)
  * Added forgeblocks.com to psl (#1238)
  * Update atl/njs/ric.jelastic.vps host.net (#1242)
  * util: gTLD data autopull updates for 2021-03-24T15:07:34 UTC (#1243)
  * add paywhirl.com for site users (#1237)
  * Add shiftcrypto.dev and shiftcrypto.io (#1236)
  * Add hra.health to PSL (#1234)
  * Add multibaas.app and multibaas.com (#1233)
  * added service magnet to PSL (#1232)
  * Add subdomains of pythonanywhere.com and eu.pythonanywhere.com (#1229)
  * Add cafjs.com (#1228)
  * Update public_suffix_list.dat (#1225)
  * Switch the TLD update workflow to daily (#1226)
  * util: gTLD data autopull updates for 2021-03-04T15:37:37 UTC (#1224)
  * Update Email address for GOV.UK PaaS (#1220)
  * Add Clerk staging domains, change email to systems@ (#1222)
  * sourcehut: add srht.site (#1218)
  * Add cloudsite.builders (#1219)
  * Add service.gov.scot (#1221)
  * Add framer.app and framercanvas.com to PSL (#1217)
* Tue Feb 23 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 20210221:
  * Add noticeable.news (#1216)
  * CI: remove "labels" config from tld-update.yml workflow. (#1215)
  * util: gTLD data autopull updates for 2021-02-20T20:31:36 UTC (#1214)
  * Update .my in ICANN section (#1213)
  * Add edgecompute.app (#1212)
  * tools: improved newgtlds.go, removed replace-between. (#1204)
  * Update PSL for broader use-cases for northflank.app and code.run domains. (#1210)
  * Added eurodir.ru (#1207)
* Thu Feb 11 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 20210211:
  * Add mcpre.ru, mcdir.me to mchost.ru subsection (#1206)
  * Add awsglobalaccelerator.com (#1199)
  * Add northflank.app and code.run to PSL (#1198)
  * gTLD autopull: 2021-02-07 (#1203)
* Mon Feb  1 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 20210128:
  * Add Appspace to PSL (#1197)
  * add torproject.net (#1196)
  * Public suffixes KU Leuven (#1194)
  * added clickrising.net (#1192)
  * Add hosting and paas from OVHcloud (#1193)
  * add missing IDN ccTLDs:  for Bahrain and Laos ( .xn--mgbcpq6gpa1a and .xn--q7ce6a ) (#1175)
  * Add try-snowplow.com to PSL (#1184)
  * Update public_suffix_list.dat (#1189)
  * Update public_suffix_list.dat (#1187)
  * removal of scapp.io and applicationcloud.io (#1186)
  * Update public_suffix_list.dat (#1185)
  * Added fireweb.app to PSL (#1181)
  * Update and rename tld-update.yml to tld-update.yml.hold
  * CI: Add Github Actions workflow for TLD updates PRs. (#1166)
* Mon Jan 11 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 20210108:
  * Added ghost.io to PSL (#1180)
  * Add myshopify.com (#1179)
* Mon Dec 28 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 20201223:
  * gTLD autopull: 2020-12-21 (#1172)
  * Featherhead: Remove defunct project (#1171)
  * Add needed suffixes for WPMU DEV hosting and CDNs (#1169)
  * Add GünstigBestellen domains (#1170)
  * add deno.dev (#1167)
  * Update WoltLab Cloud Domains (#1168)
  * gTLD autopull: 2020-12-11 (#1165)
  * Update public_suffix_list.dat (#1162)
  * Add lohmus.me to the private section (#1161)
  * Add flap.id domain (#1160)
  * UPDATE TO SLD ON HOSTBIP SECTION (#1130)
  * Third level .рус domains for the PRIVATE section (#1159)
  * Add orsites.com to the list of domains (#1157)
  * Add webthings.io and krellian.net (#1154)
  * gTLD autopull: 2020-12-10 (#1164)
  * gTLD autopull: 2020-11-30 (#1155)
  * The list of Jelastic public domains was extended. Addition to #1023 #1063 #1092 #1095 (#1151)
  * gTLD autopull: 2020-11-21 (#1152)
  * Add ondigitalocean.app to the list of domains (#1150)
  * Add private domains for airy.host (#1149)
  * gTLD autopull: 2020-11-11 (#1148)
  * Update public_suffix_list.dat (#1147)
  * Add of.je (#1131)
  * Update the existing Names.of.London Public List (#1146)
  * Del linkitools.space nxd from Private (#1145)
  * Del ptplus.fit NXD from Private (#1144)
  * Del cloudeity.net NXD from Private (#1143)
  * Del uklugs.org NXD from Private section (#1142)
  * Del xenapponazure.com from Private (#1141)
  * Added an RSS feed URL (#1140)
  * gTLD autopull: 2020-11-03 (#1139)
  * Add secaas.hk (#1138)
  * Adding qoto.io (#1129)
  * Add fh-muenster.io to PSL (#1134)
  * gTLD autopull: 2020-10-28 (#1135)
  * Update pull_request_template.md (#1116)
* Tue Oct 27 2020 andreas.stieger@gmx.de
- Update to version 20201026:
  * gTLD autopull: 2020-10-12
  * Remove algorithmia.com
  * Add azurestaticapps.net dns suffixes
  * Adds *.gateway.dev
  * Add cdn-edges.net
  * Sort Alphabet entries by TLD first and then by SLDD
  * Add service.one as a public suffix
  * Add tlon.network
  * Add iopsys.se
  * The list of Jelastic public domains was extended
  * Add wapblog's domain
  * added localzone.xyz
  * Adds translate.goog and tr-test.goog
  * Add bip.sh
  * Add .tm.dz
  * Add js.wpenginepowered.com
  * Updated comments with new URLs to the different lists of domains
* Sat Sep 12 2020 andreas.stieger@gmx.de
- Update to version 20200909:
  * Update gTLD list to 2020-09-09
  * Add pages.dev
  * Add gsj.bz
  * Added gitapp.si
  * Add small-web.org domain under Small Technology Foundation
  * Update to ICANN and private SLDs on CentralNic registry platform
  * The list of Jelastic public domains was extended
  * Add forte.id
  * Add Danger Science Group domains
  * Switch cloud.metacentrum.cz from suffix to wildcard notation
  * Added mcpe.me
  * Add omniwe.site
  * Add GOV.UK Pay test environment domain
* Fri Aug 14 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 20200810:
  * Add algorithmia.com (#1071)
  * Added Mythic Beasts (#1075)
  * gTLD autopull: 2020-08-07 (#1085)
  * add rdv.to domains for pcarrier.ca Software Inc. (#1039)
  * thingdust AG: added in-house domains of internal services (#1031)
  * Add mcdir.ru and vps.mcdir.ru (#1051)
  * Add na4u.ru to list (#998)
  * gTLD autopull: 2020-07-29 (#1079)
  * gTLD autopull: 2020-07-28 (#1077)
  * add impertrix.com and impertrixcdn.com (#1060)
  * gTLD autopull: 2020-07-18 (#1069)
  * Add 12 sub zones to .br [20200714 update] (#1068)
* Thu Jul 16 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 20200715:
  * Add cn.vu (#987)
  * Add opensocial.site (#1056)
  * Add wpenginepowered.com (#1064)
  * The list of Jelastic public domains was extended. Addition to #1023 (#1063)
  * Update platform.sh (#1061)
  * add pages.wiardweb.com (#1035)
  * Update public_suffix_list.dat (#1036)
  * gTLD autopull: 2020-06-27 (#1059)
  * Removal of education.tas.edu.au (#977)
  * gTLD autopull: 2020-06-24 (#1057)
  * gTLD autopull: 2020-06-20 (#1055)
* Fri Jun 19 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 20200616:
  * Fix broken links in nic.lk (#1053)
  * Remove fastpanel.direct for FASTVPS EESTI OU (#1024)
  * Add gitpage.si to private domains section (#1013)
  * add hostyhosting.io (#1046)
  * Add wien.funkfeuer.at to private section (#1041)
  * Update public_suffix_list.dat (#1029)
  * Update public_suffix_list.dat (#1050)
  * Add plesk.page and pleskns.com suffix to private section (#1048)
  * gTLD autopull: 2020-06-11 (#1049)
  * gTLD autopull: 2020-06-05 (#1047)
  * gTLD autopull: 2020-05-28 (#1045)
  * gTLD autopull: 2020-05-27 (#1044)
  * add g.vbrplsbx.io domain (#994)
  * Jelastic public domains are added (#1023)
  * Add vercel.app and vercel.dev and update now.sh listing in private section (#1019)
  * Add *.backyards.banzaicloud.io and *.banzai.cloud (#1025)
  * add seidat.net private domain (#974)
  * Added gentlentapis.com (#984)
  * Update public_suffix_list.dat (#1037)
  * Remove bitballoon.com and netlify.com (#1020)
  * Add *.owo.codes (#973)
  * Add plesk.page and pdns.page suffix to private section (#1022)
  * Add kasserver.com to Private Section (#1016)
  * Update Linode PSL entries (#1026)
  * Add fly.io suffixes (#1015)
  * Update public_suffix_list.dat (#1000)
  * Add Voxel.sh DNS public suffixes (#1014)
* Mon May 18 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 20200506 (bsc#1171819):
  * gTLD autopull: 2020-05-06 (#1030)
  * Update public_suffix_list.dat (#993)
  * Add shopware.store domain (#958)
  * Add clic2000.net to Private Section (#1010)
  * Add Fabrica apps domain: onfabrica.com (#999)
  * Add dyndns.dappnode.io (#912)
  * Added curv.dev to public_suffix_list.dat (#968)
  * Add panel.gg and daemon.panel.gg (#978)
  * adding sth.ac.at (#997)
  * Add netlify.app (#1012)
  * Added Wiki Link as info resource (#1011)
  * Add schulserver.de, update IServ GmbH contact information (#996)
  * Add conn.uk, copro.uk, couk.me and ukco.me domains (#963)
  * Remove flynnhub.com (#971)
  * Added graphox.us domain (#960)
  * Add domains for FASTVPS EESTI OU (#941)
  * Add platter.dev user app domains (#935)
  * Add playstation-cloud.com (#1006)
  * gTLD autopull: 2020-04-02 (#1005)
  * ACI prefix (#930)
  * Update public_suffix_list.dat (#923)
  * Add toolforge.org and wmcloud.org (#970)
  * gTLD autopull: 2020-03-29 (#1003)
* Sat Mar 28 2020 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 20200326:
  * aero registry removal
  * Add Mineduc subregistry for public schools: aprendemas.cl
  * Update public_suffix_list.dat - Existing Section
  * gTLD autopull: 2020-03-15
  * Add "urown.cloud" and "dnsupdate.info"
  * Remove site.builder.nu
  * Remove unnecessary trailing whitespace for name.fj
  * Update .eu IDNs to add Greek and URL for Cyrillic
  * Update fj entry
* Tue Feb  4 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 20200201:
  * gTLD autopull: 2020-02-01 (#952)
  * gTLD autopull: 2020-01-31 (#951)
  * Add WoltLab Cloud domains (#947)
  * Add qbuser.com domain (#943)
  * Added senseering domain (#946)
  * Add u.channelsdvr.net to PSL (#950)
  * Add discourse.team (#949)
  * gTLD autopull: 2020-01-06 (#942)
  * gTLD autopull: 2019-12-25 (#939)
  * Urgent removal of eq.edu.au (#924)
  * gTLD autopull: 2019-12-20 (#938)
  * gTLD autopull: 2019-12-11 (#932)
  * Added adobeaemcloud domains (#931)
  * Add Observable domain: observableusercontent.com. (#914)
  * Correct v.ua sorting
  * add v.ua (#919)
  * Add en-root.fr domain (#910)
  * add Datawire private domain (#925)
  * Add amsw.nl private domain to PSL (#929)
  * Add *.on-k3s.io (#922)
  * Add *.r.appspot.com to public suffix list (#920)
  * Added gentapps.com (#916)
  * Add oya.to (#908)
  * Add Group 53, LLC Domains (#900)
  * Add perspecta.cloud (#898)
  * Add 0e.vc to PSL (#896)
  * Add skygearapp.com (#892)
  * Update Hostbip Section (#871)
  * Add qcx.io and *.sys.qcx.io (#868)
  * Add builtwithdark.com to the public suffix list (#857)
  * Add_customer-oci.com (#811)
  * Move out old .ru reserved domains
  * gTLD autopull: 2019-12-02 (#928)
  * gTLD autopull: 2019-11-20 (#926)
* Mon Nov 18 2019 andreas.stieger@gmx.de
- Update to version 20191115:
  * Add gov.scot for Scottish Government
  * update gTLD list to 2019-11-15 state
  * remove go-vip.co, go-vip.net, wpcomstaging.com
* Sat Oct 26 2019 andreas.stieger@gmx.de
- Update to version 20191025:
  * gTLD list updated to 2019-10-24 state
  * Update .so suffix list
  * Add the new TLD .ss
  * Add xn--mgbah1a3hjkrd (موريتانيا)
  * Add lolipop.io
  * Add altervista.org
  * Remove zone.id from list
  * Add new domain to Synology dynamic dns service
* Tue Aug 13 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 20190808:
  * tools: update newgtlds.go to filter removed gTLDs (#860)
  * gTLD autopull: 2019-08-08 (#862)
  * Remove non-public nuernberg.museum nuremberg.museum domains (#859)
  * gTLD autopull: 2019-08-02 (#858)
  * Update public_suffix_list.dat (#825)
  * Update reference as per #855
  * add nic.za
  * Update contact for SymfonyCloud (#854)
  * Add lelux.site (#849)
  * Add *.webhare.dev (#847)
  * Update Hostbip Section (#846)
  * Add Yandex Cloud domains (#850)
  * Add ASEINet domains (#844)
  * Update nymnom section (#771)
  * Add Handshake zones (#796)
  * Add iserv.dev for IServ GmbH (#826)
  * Add trycloudflare.com to Cloudflare's domains (#835)
  * Add shopitsite.com (#838)
  * Add pubtls.org (#839)
  * Add qualifio.com domains (#840)
  * Update newgtlds tooling & associated gTLD data. (#834)
  * Add web.app for Google (#830)
  * Add iobb.net (#828)
  * Add cloudera.site (#829)
* Wed May 29 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 20190529:
  * Add Balena domains (#814)
  * Add KingHost domains (#827)
  * Add dyn53.io (#820)
  * Add azimuth.network and arvo.network (#812)
  * Update .rw domains per ccTLD (#821)
  * Add b-data.io (#759)
  * Add co.bn (#789)
  * Add Zitcom domains (#817)
  * Add Carrd suffixes (#816)
  * Add Linode Suffixes (#810)
  * Add lab.ms (#807)
  * Add wafflecell.com (#805)
  * Add häkkinen.fi (#804)
  * Add prvcy.page (#803)
  * Add SRCF user domains: soc.srcf.net, user.srcf.net (#802)
  * Add KaasHosting (#801)
  * Adding cloud66.zone (#797)
  * Add gehirn.ne.jp and usercontent.jp for Gehirn Inc. (#795)
  * Add Clerk user domains (#791)
  * Add loginline (.app, .dev, .io, .services, .site) (#790)
  * Add wnext.app (#785)
  * Add Hostbip Registry Domains (#770)
  * Add glitch.me (#769)
  * added thingdustdata.com (#767)
  * Add dweb.link (#766)
  * Add onred.one (#764)
  * Add mo-siemens.io (#762)
  * Add Render domains (#761)
  * Add *.moonscale.io (#757)
  * Add Stackhero domain (#755)
  * Add voorloper.cloud (#750)
  * Add repl.co and repl.run (#748)
  * Add edugit.org (#736)
  * Add Hakaran domains (#733)
  * Add barsy.ca (#732)
  * Add Names.of.London Domains (#543)
  * Add nctu.me (#746)
  * Br 201904 update (#809)
  * Delete DOHA
  * Add app.banzaicloud.io (#730)
  * Update .TR (#741)
  * Add Nabu Casa (#781)
  * Added uk0.bigv.io under Bytemark Hosting (#745)
  * Add GOV.UK PaaS client domains (#765)
  * Add discourse.group for Civilized Discourse Construction Kit, Inc. (#768)
  * Add on-rancher.cloud and on-rio.io (#779)
  * Syncloud dynamic dns service (#727)
  * Add git-pages.rit.edu (#690)
  * Add workers.dev (#772)
  * Update .AM (#756)
  * Add go-vip.net. (#793)
  * Add site.builder.nu (#723)
  * Update .FR sectorial domains (#527)
  * Remove ACTIVE
  * Remove SPIEGEL
  * Remove EPOST
  * Remove ZIPPO
  * Remove BLANCO
* Mon Feb 18 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 20190205:
  * Add domains of Individual Network Berlin e.V. (#711)
  * Added bss.design to PSL (#685)
  * Add fastly-terrarium.com (#729)
  * Add Swisscom Application Cloud domains (#698)
  * Update public_suffix_list.dat with api.stdlib.com (#751)
  * Add regional domain for filegear.me (#713)
  * Remove bv.nl (#758)
  * Update public_suffix_list.dat
* Tue Feb 12 2019 Fridrich Strba <fstrba@suse.com>
- Link public_suffix_list.dat to effective_tld_names.dat for the
  purpose of httpcomponents-client
* Fri Jan 18 2019 Tomáš Chvátal <tchvatal@suse.com>
- Do not pull in full python3, psl-make-dafsa already pulls in
  what it needs to generate the things
* Sat Jan  5 2019 astieger@suse.com
- Update to version 20181227:
  * Add run.app and a.run.app to the psl (#681)
  * Add telebit.io .app .xyz (#726)
  * Add Leadpages domains (#731)
  * Add public suffix entries for dapps.earth (#708)
  * Add Bytemark Hosting domains (#620)
  * Remove .STATOIL
  * linter: Expect rules to be in NFKC (#725)
  * Convert list data from NFKD to NFKC (#720)
  * Update LS (#718)
* Tue Oct 30 2018 astieger@suse.com
- Update to version 20181030:
  * Add readthedocs.io (#722)
  * Remove trailing whitespace from L11948 (#721)
  * Add krasnik.pl, leczna.pl, lubartow.pl, lublin.pl, poniatowa.pl
    and swidnik.pl domains to the Public Suffix List (#670)
  * Add instantcloud.cn by Redstar Consultants (#696)
  * Add Fermax and mydobiss.com domain (#706)
  * Add shop.th & online.th (#716)
  * Add siteleaf.net (#655)
  * Add wpcomstaging.com and go-vip.co to the PSL (#719)
* Mon Oct 15 2018 astieger@suse.com
- Update to version 20181003:
  * Remove deleted TLDs (#710)
  * Added apigee.io (#712)
  * Add AWS ElasticBeanstalk Ningxia, CN region (#597)
  * Add Github PULL REQUEST TEMPLATE (#699)
  * Add ong.br 2nd level domain (#707)
* Wed Aug 15 2018 astieger@suse.com
- Update to version 20180813:
  * Update .ID list (#703)
  * Updated .bn ccTLD. Removed wildcard. (#702)
  * Remove stackspace.space from PSL (#691)
  * Remove XPERIA (#697)
* Tue Jul 24 2018 astieger@suse.com
- Update to version 20180719:
  * Remove .IWC
  * Update Kuwait's ccTLD (.kw)
  * htts://www.transip.nl => https://www.transip.nl
  * Remove MEO and SAPO
* Tue May 29 2018 astieger@suse.com
- Update to version 20180523:
  * Remove 1password domains (#632)
  * Add cleverapps.io (Clever Cloud) (#634)
  * Remove .BOOTS
  * Add azurecontainer.io to Microsoft domains (#637)
  * Change the patchnewgtlds tool for the updated .zw domain
  * Add new gTLDs up to 2018-04-17 and new ccTLDs up to 2018-04-17
  * cloud.muni.cz cloud subdomains (#622)
  * Add YunoHost DynDns domains: nohost.me & noho.st (#615)
  * Use a custom token for the newGTLD list (#645)
  * lug.org.uk (#514)
  * Adding xnbay.com,u2.xnbay.com,u2-local.xnbay.com to public_suffix_list.dat. (#506)
  * Adding customer.speedpartner.de (#585)
  * Adding ravendb.net subdomains (#535)
  * Adding own.pm (#544)
  * pcloud.host (#531)
  * Add additional Lukanet Ltd domains (#652)
  * Add zone.id (#575)
  * Add half.host (#571)
  * Update 香港 TLD (#568)
  * Add Now-DNS domains (#560)
  * Added blackbaudcdn.net private domain to PSL (#558)
  * Adding IServ GmbH domains (#552)
  * Add FASTVPS EESTI OU domains (#541)
  * nic.it - update regions and provinces (#524)
  * Update Futureweb OG Private Domains (#520)
  * add United Gameserver virtualuser domains (#600)
  * Add Lightmaker Property Manager, Inc domains (#604)
  * Update Uberspace domains (#616)
  * Add Datto, Inc domains
  * Add memset hosting domains (#625)
  * Add utwente.io (#626)
  * Add bci.dnstrace.pro (#630)
  * Add May First domains (#635)
  * Add Linki Tools domains (#636)
  * Update NymNom domains
  * Add Co & Co domains (#650)
  * Add new gTLDs up to 2018-05-08 (#653)
  * Correct linter issues (#654)
  * Add cnpy.gdn as private domain (#633)
  * Add freedesktop.org (#619)
  * Add Omnibond Systems (#656)
  * Add hasura.app to the list (#668)
  * Update gu ccTLD suffixes (#669)
* Fri Apr  6 2018 mpluskal@suse.com
- Update to version 20180328:
  * Add gwiddle.co.uk (#521)
  * Add ox.rs (#522)
  * Add myjino.ru (#512)
  * Add ras.ru domains (#511)
  * Add AWS ElasticBeanstalk Osaka, JP region (#628)
  * Remove trailing whitespace (#621)
* Tue Mar 13 2018 astieger@suse.com
- Update to version 20180312:
  * Add Cloudeity customer subdomains
  * Removed se.com
  * .br updated - one new city domain barueri.br
- use %%license (bsc#1082318)
* Wed Feb 28 2018 astieger@suse.com
- Update to version 20180223:
  * Add mozilla-iot.org (#605)
* Tue Feb 20 2018 astieger@suse.com
- update to 20180218:
  * Add YesCourse private entry for official.academy
  * Add schokokeks.net
  * Add 2038.io
  * Adding cloud66.ws customer domain for Cloud66
  * Add linkyard.cloud
* Fri Jan 26 2018 astieger@suse.com
- Update to version 20180125:
  * .br updated - 12 new 2nd level city domains
  * Update .ke suffixes to include second-level domains
  * Remove myfusion.cloud domain
* Fri Jan  5 2018 mpluskal@suse.com
- Update to version 20171228:
  * Add Paris region (#579)
  * Fixed alwaysdata.net. (#555)
  * Add Combell domains (#565)
  * Adding scrysec.com (#528)
  * Add Fedora Openshift app domains (#533)
  * Add resin.io device domains to list (#499)
  * Add nh-serv.co.uk to list file (#491)
  * Add 1Password domains (#562)
  * Add s5y.io (#572)
  * Add social domains - NIC.bo (#467)
* Tue Nov  7 2017 astieger@suse.com
- Update to version 20171028:
  * remove .htc TLD (#548)
  * Delete "REMOVED" TLDs (#536)
  * .br updated - 19 new 2nd level city domains (#546)
* Mon Oct  9 2017 mpluskal@suse.com
- Update to version 20170910:
  * Add pixolino.com domain (#456)
  * Add Fancy Bits domains to the PSL (#495)
  * Update AWS Elastic Beanstalk domains. (#484)
  * Add domreg.merit.edu registry (#293)
  * Update WeDeploy/Liferay domains. (#510)
  * Add v-info.info (#508)
  * Add debian.net (#516)
  * .br updated - 18 new 2nd level city domains (#507)
* Fri Aug 18 2017 astieger@suse.com
- Update to version 20170809:
  * Update Futureweb OG Private Domains (#498)
  * Add byen.site (#490)
* Thu Jul 20 2017 astieger@suse.com
- Update to version 20170713:
  * Add newly delegated ICANN ccTLDs based on 2017-07-10 database (#483)
  * Add boomla.net domain (#476)
  * Add Dynu.com domain names to the PSL (#447)
  * Add Netlify domains (#469)
  * add Nodeart domains (#471)
  * Add additional evennode.com domains (#481)
  * Add LiquidNet domains (#452)
  * Add NymNom domains (#425)
  * Add Sub 6 Limited domains (#462)
  * Pull request for adding org.ru, net.ru and pp.ru names (#412)
* Mon Jul  3 2017 astieger@suse.com
- Update to version 20170622:
  * .br updated 2nd level domains + 3rd level gov.br (#464)
  * Adding WeDeploy domains (#420)
  * Add nodum.io aPaas (#431)
  * Add Filegear domain (#434)
  * Add Lukanet Ltd domains (#439)
  * Add metacentrum.cz cloud subdomains (#438)
  * Add flynnhosting.net for Flynn (#459)
  * Add lima-city/TrafficPlex domains (#454)
  * Add mytuleap.com domain (#453)
  * Add lcube-server.de, svn-repos.de, git-repos.de (#455)
  * Added Thingdusts per-user subdomains. (#419)
  * Update XS4ALL domains (#457)
  * Add CloudAccess.net domains (#466)
  * Add info.cx (#460)
  * Add DrayDNS domains (#475)
  * Update GitHub domains
* Mon Jun 12 2017 astieger@suse.com
- Update to version 20170608:
  * Add nom.nc (#305)
  * Add definima domain suffix (#383)
  * Sort by company
  * Delete .ORIENTEXPRESS (#437)
  * Add cloud.goog (#449)
* Tue May  9 2017 astieger@suse.com
- Update to version 20170424:
  * Additional evennode.com domains (#428)
  * Update .zw extensions (#369)
  * Add Ici la Lune hosting domain (#370)
  * Update Daplie, Inc domains (#388)
  * Add XS4ALL Internet bv domains (#397)
  * Add Octopodal Solutions, LLC domains (#404)
  * Add Cloud66 domains (#409)
  * Add A.W. AdvisorWebsites.com Software Inc domains (#413)
  * Add Fedora domains (#414)
  * Add Synology, Inc. domains (#415)
  * Correct Fedora domain sorting
  * Adding IPiFony Systems, Inc. domains (#429)
  * Add Uberspace domains (#432)
  * Add SensioLabs, SAS domains (#423)
  * Update .ar ccTLD (#406)
  * Update .ไทย domains (#408)
  * Add Qutheory, LLC domains (#407)
  * Adding Quip domains (#427)
  * Add eDirect Corp domains (#398)
  * Add bplaced network domains (#433)
  * Add Mail.ru Group domains (#421)
  * Update Platform.sh / Commerce Guys SAS domains (#417)
  * Formatting
* Tue Apr  4 2017 tchvatal@suse.com
- Update to version 20170331:
  * Include fastly.net subdomain for related services (#424)
* Thu Mar 16 2017 astieger@suse.com
- Update to version 20170303:
  * Add new gTLDs up to 2017-02-23 (#405)
  * adding storj.farm for Storj Labs Inc. (#400)
* Fri Feb 10 2017 astieger@suse.com
- Update to version 20170206:
  * Add additional private Fastly domains (#371)
  * Add onion (#386)
  * Removing s3.amazonaws.com wildcard, adding AWS eu-west-2 regional endpoints (#387)
  * Add .RU and .SU geographic suffixes owned by FAITID (#384)
* Sat Jan 14 2017 mpluskal@suse.com
- Update to version 20170105:
  * Add Amune.org to Public Suffix List (#357)
  * Adding TwoDNS TLD's to public_suffix_list.dat (#328)
  * Remove ro.com from Public Suffix List (#346)
  * Add 1gb.ua domains (#353)
  * Add homeoffice.gov.uk (#342)
  * Update list of .RU reserved domains (#359)
  * Add remotewd.com for Western Digital
- Enable syntax checks
* Wed Dec 14 2016 astieger@suse.com
- Update to version 20161211:
  * Remove volgograd.ru from Public Suffix List (#340)
  * Add user.party.eus to PRIVATE section (#348)
  * Adding wildcard for *.s3.amazonaws.com, ca-central-1 AWS region and changing Amazon contact info (#351)
  * Added on-web.fr (Planet-Work shared hosting) (#349)
  * Added .ni as a valid user registerable domain. (#336)
  * Sort .NI
* Sat Dec  3 2016 mpluskal@suse.com
- Update to version 20161128:
  * Update Futureweb OG Private Domains (#332)
  * DynamicDNS and Portmapping Service Feste-IP.net (#295)
  * Added Enonic Cloud domains to list (#330)
  * Added dynamic domains for Yombo (#331)
  * Update Amazon AWS domains (#259)
  * Merge new gTLDs up through 2016-11-29 (#341)
- Use _service for easier updating
* Tue Nov 22 2016 astieger@suse.com
- build compact DAFSA format of the list
* Mon Nov 14 2016 astieger@suse.com
- 2016-11-10 update:
  * Add sinacloud domains: appchizi.com, applinzi.com
  * Add apps.lair.io and stolos.io
  * Add ddnss.org domains
  * Update .JP suffix
  * Add Securepoint Dynamic DNS domains
  * Add now.sh
  * Add shiftedit.io
* Mon Oct 24 2016 astieger@suse.com
- 2016-10-21 update:
  * Update .mz suffixes according to registry
  * Add Futureweb OG Private Domains
  * Add alwaysdata.net
  * Add publishproxy.com
  * Add TAIFUN Software AG domains
  * Add Revitalised Limited domains
  * Add opencraft.hosting
  * Add KnightPoint Systems domain
  * Brazilian .leg.br
  * Add Keyweb AG domains
  * Add ClouDNS domains
  * Add TransIP domains
  * Add .cy suffix
  * Add myfusion.cloud
* Tue Aug 30 2016 astieger@suse.com
- 2016-08-26 update:
  * update .krd
  * Add js.org
  * Move lib.de.us to private section
  * Add wmflabs.orgf
  * Add new gTLSs up to 2016-08-17
  * Add bnr.la
  * Add Joyent Triton
  * Add protonet.io
* Mon Aug  8 2016 astieger@suse.com
- 2016-08-05 update:
  * Add myasustor.com
  * Add myqnapcloud domains
* Mon Aug  1 2016 astieger@suse.com
- 2016-07-31 update:
  * Add meteorapp.com
  * Add Drud domains
  * Add backplaneapp.io
  * Add gitlab.io
  * Add static.land
  * Add stackspace.space
  * Add browsersafetymark.io
* Mon Jul  4 2016 astieger@suse.com
- 2016-07-03 update:
  * Add mycd.eu
  * Add beep.pl
  * Add hepforge.org
  * Add certmgr.org
  * Add fhapp.xyz
  * Update .jp suffixes
  * Add tuxfamily.com
  * Add evennode.com
  * Add realm.cz
  * Add logoip.de, logoip.com
  * Add virtueldomein.nl
  * Add *.magnetosite.cloud
  * Add cyryptonomic.net
  * Correct Amazon AWS EC2 China
  * Add hasura-app.io.
  * Update .BA suffixes
* Fri Jun 10 2016 astieger@suse.com
- 2016-06-10 update:
  * Add spacekit.io
  * Add potager.org domains
  * Add boxfuse.io
* Fri May 27 2016 astieger@suse.com
- 2016-05-25 update:
  * Add No-IP.com's domains
  * Add pgfog.com
  * Add Freebox domains
  * Add e4.cz
  * Add skyhat.io
  * Add dy.fi, tunk.org
  * Update .jp
* Tue May 10 2016 astieger@suse.com
- 2016-05-09 update:
  * Add new gTLDs up to 2016-05-09
  * Add dnshome.de
* Fri Apr 22 2016 astieger@suse.com
- 2016-04-20 update:
  * Add ownprovider.com for OwnProvider
  * Add nerdpol.ovh part of nsupdate.info dyndns service
  * Add townnews customer domain suffixes
  * Add on-aptible.com
  * Add router.management
  * Add compute.estate and alces.network
  * Update .zm TLD
  * Add GoIP DNS Services
  * Add chirurgiens-dentistes-en-france.fr
  * Add myfritz.net for AVM
  * Add nsupdate.info dyndns service
  * Add dedyn.io
  * Google: Add *.0emm.com
  * Add daplie.me
  * Add hzc.io
  * Add new gTLDs up to 2016-04-04
* Thu Mar 31 2016 idonmez@suse.com
- 2016-03-15 update:
  * add .xn--e1a4c, oy.lc
  * add new gTLDs through 2016-03-25
* Sat Mar 12 2016 astieger@suse.com
- 2016-03-10 update:
  * add co.dk, biz.dk, firm.dk, store.dk, reg.dk
  * add cyon.link and cyon.site
  * remove patheon.io, add patheonsite.io
* Sun Mar  6 2016 astieger@suse.com
- 2016-03-02 update:
  * add apps.fbsbx.com
  * update github list
  * add new gTLDs up through 2016-03-01
* Fri Feb 19 2016 astieger@suse.com
- 2016-02-19 update:
  * Add xenapponazure.com to the PSL
  * Add dynv6 dynamic DNS service
  * Add new .pro suffixes
  * Update AWS domains
* Tue Feb  2 2016 psimons@suse.com
- 2016-02-02 update:
  * add *.i.ng
  * update ng reference URL
  * sort entries alphabetically
* Fri Jan 29 2016 astieger@suse.com
- 2016-01-29 update:
  * Add Drobo Dynamic DNS service
  * add TLD .co.cz
  * Minor change for .rs and .срб (xn--90a3ac) domains
  * Add prgmr.com customer domain suffix
* Thu Jan 21 2016 astieger@suse.com
- 2016-01-15 update:
  * Clean-up some inconsistency of data
  * Add additional entries to .GY ccTLD
  * Remove .TP, TLD has been decommissioned
  * Renamed agrica.za to agric.za
* Thu Jan  7 2016 astieger@suse.com
- 2016-01-06 update:
  * Add cloudfunctions.net to Google, Inc. section
  * Add new gTLDs up to 2016-01-04
* Mon Dec  7 2015 astieger@suse.com
- update to 20151205
* Tue Dec  1 2015 astieger@suse.com
- update to 20151130:
  * Remove .an domains from the list (deleted from root zone).
  * Update .ni to have explicit list.
  * Remove taxi.aero, marketplace.aero
* Sun Nov 15 2015 astieger@suse.com
- initial package for openSUSE / SLE based on Fedora spec
- update to 20151112
